#!/bin/sh

time=`uptime | sed -e 's/.*p *//' -e 's/, l.*//' -e 's/  / /'`
temp=`cat /sys/devices/platform/omap34xx_temp/temp1_input | awk '{ sub(/-/,""); print $1" °C"}'`
kernel=`uname -r |grep -c 2.6.28-omap1`

if [ "$kernel" -eq "1" ]
	then
		temptit=`echo "Titan not installed!!!"`
	else
		temptit=`echo `cat /sys/class/power_supply/bq27200-0/temp` °C`
fi

timetemp="
Uptime\				 		=   $time\			
Temperature (Original Kernel)\	=   $temp\		
Temperature (Titan)	 	=   $temptit"

zenity --info --title="Uptime and Temperature" --text="$timetemp"
